@@ -1,5 +1,5 @@
-from evalgraph.scenarios import Scenario, BaseScenario
-from evalgraph.scenariocontext import ScenarioContext
+from evalgraph.core.scenarios import Scenario, BaseScenario
+from evalgraph.core.scenariocontext import ScenarioContext
 from evalgraph.option import Underlier, Option
 
 class SpotShiftScenario(Scenario):
